==> vradi-entities-0.0.1-sources.jar: com/jurismarches/vradi/entities/Client.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Client extends BusinessEntity, QueryMaker {

	static final public String EXT_CLIENT = "Client";

    static final public String FIELD_NAME = "name";
    static final public String FQ_FIELD_NAME = EXT_CLIENT + ".name";
    static final public String FIELD_EMAIL = "email";
    static final public String FQ_FIELD_EMAIL = EXT_CLIENT + ".email";
    static final public String FIELD_CREATIONDATE = "creationDate";
    static final public String FQ_FIELD_CREATIONDATE = EXT_CLIENT + ".creationDate";
    static final public String FIELD_VALIDEMAIL = "validEmail";
    static final public String FQ_FIELD_VALIDEMAIL = EXT_CLIENT + ".validEmail";
    static final public String FIELD_ADDRESS = "address";
    static final public String FQ_FIELD_ADDRESS = EXT_CLIENT + ".address";
    static final public String FIELD_PHONE = "phone";
    static final public String FQ_FIELD_PHONE = EXT_CLIENT + ".phone";
    static final public String FIELD_CONTACT = "contact";
    static final public String FQ_FIELD_CONTACT = EXT_CLIENT + ".contact";
    static final public String FIELD_USER = "user";
    static final public String FQ_FIELD_USER = EXT_CLIENT + ".user";
    static final public String FIELD_SENDING = "sending";
    static final public String FQ_FIELD_SENDING = EXT_CLIENT + ".sending";

    public void setName(String name);
    public String getName();


    public void setEmail(String email);
    public String getEmail();


    public void setCreationDate(Date creationDate);
    public Date getCreationDate();


    public void setValidEmail(boolean validEmail);
    public boolean getValidEmail();


    public void setAddress(String address);
    public String getAddress();


    public void setPhone(String phone);
    public String getPhone();


    public void setContact(String contact);
    public String getContact();

    public Set<String> getUser();
    public void addUser(String element);
    public void removeUser(String element);
    public void clearUser();

    public Set<String> getSending();
    public void addSending(String element);
    public void removeSending(String element);
    public void clearSending();


} //Client

==> vradi-entities-0.0.3-sources.jar: com/jurismarches/vradi/entities/Client.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Client extends BusinessEntity, QueryMaker {

	static final public String EXT_CLIENT = "Client";

    static final public String FIELD_NAME = "name";
    static final public String FQ_FIELD_NAME = EXT_CLIENT + ".name";
    static final public String FIELD_EMAIL = "email";
    static final public String FQ_FIELD_EMAIL = EXT_CLIENT + ".email";
    static final public String FIELD_CREATIONDATE = "creationDate";
    static final public String FQ_FIELD_CREATIONDATE = EXT_CLIENT + ".creationDate";
    static final public String FIELD_VALIDEMAIL = "validEmail";
    static final public String FQ_FIELD_VALIDEMAIL = EXT_CLIENT + ".validEmail";
    static final public String FIELD_ADDRESS = "address";
    static final public String FQ_FIELD_ADDRESS = EXT_CLIENT + ".address";
    static final public String FIELD_PHONE = "phone";
    static final public String FQ_FIELD_PHONE = EXT_CLIENT + ".phone";
    static final public String FIELD_CONTACT = "contact";
    static final public String FQ_FIELD_CONTACT = EXT_CLIENT + ".contact";
    static final public String FIELD_GROUP = "group";
    static final public String FQ_FIELD_GROUP = EXT_CLIENT + ".group";
    static final public String FIELD_USER = "user";
    static final public String FQ_FIELD_USER = EXT_CLIENT + ".user";
    static final public String FIELD_SENDING = "sending";
    static final public String FQ_FIELD_SENDING = EXT_CLIENT + ".sending";

    public void setName(String name);
    public String getName();


    public void setEmail(String email);
    public String getEmail();


    public void setCreationDate(Date creationDate);
    public Date getCreationDate();


    public void setValidEmail(boolean validEmail);
    public boolean getValidEmail();


    public void setAddress(String address);
    public String getAddress();


    public void setPhone(String phone);
    public String getPhone();


    public void setContact(String contact);
    public String getContact();

    public Set<String> getGroup();
    public void addGroup(String element);
    public void removeGroup(String element);
    public void clearGroup();

    public Set<String> getUser();
    public void addUser(String element);
    public void removeUser(String element);
    public void clearUser();

    public Set<String> getSending();
    public void addSending(String element);
    public void removeSending(String element);
    public void clearSending();


} //Client
